netapp_ontap.resources.cifs_share_acl API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.cifs_share_acl`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

Access to files and folders can be secured over a network by configuring share access control lists (ACLs) on CIFS shares. Share-level ACLs can be configured by using either Windows users and groups or UNIX users and groups. A share-level ACL consists of a list of access control entries (ACEs). Each ACE contains a user or group name and a set of permissions that determines user or group access to the share, regardless of the security style of the volume or qtree containing the share. When an SMB user tries to access a share, ONTAP checks the share-level ACL to determine whether access should be granted. A share-level ACL only restricts access to files in the share; it never grants more access than the file level ACLs.

## Examples

### Creating a CIFS share ACL

To create a share ACL for a CIFS share, use the following API. Note the return_records=true query parameter used to obtain the newly created entry in the response.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsShareAcl

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsShareAcl("sh1")
        resource.permission = "no_access"
        resource.type = "windows"
        resource.user_or_group = "root"
        resource.post(hydrate=True)
        print(resource)

Try it out

    CifsShareAcl({"user_or_group": "root", "type": "windows", "permission": "no_access"})

### Retrieving all CIFS shares ACLs for a specific CIFS share for a specific SVM in the cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsShareAcl

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(CifsShareAcl.get_collection("sh1", fields="*", return_timeout=15)))

Try it out

    [
        CifsShareAcl(
            {"user_or_group": "Everyone", "type": "windows", "permission": "full_control"}
        ),
        CifsShareAcl(
            {"user_or_group": "root", "type": "windows", "permission": "no_access"}
        ),
    ]

### Retrieving a CIFS share ACLs for a user or a group of type Windows or type UNIX on a CIFS share for a specific SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsShareAcl

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsShareAcl("sh1", type="windows", user_or_group="everyone")
        resource.get()
        print(resource)

Try it out

    CifsShareAcl(
        {"user_or_group": "everyone", "type": "windows", "permission": "full_control"}
    )

### Updating a CIFS share ACLs of a user or group on a CIFS share for a specific SVM

The CIFS share ACL being modified is identified by the UUID of its SVM, the CIFS share name, user or group name and the type of the user or group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsShareAcl

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsShareAcl("sh1", type="windows", user_or_group="everyone")
        resource.permission = "no_access"
        resource.patch()

### Removing a CIFS share ACLs of a user or group on a CIFS Share for a specific SVM

The CIFS share ACL being removed is identified by the UUID of its SVM, the CIFS share name, user or group name and the type of the user or group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsShareAcl

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsShareAcl("sh1", type="windows", user_or_group="everyone")
        resource.delete()

## Classes

`class CifsShareAcl (*args, **kwargs)`

  The permissions that users and groups have on a CIFS share.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the share-level ACL on a CIFS share.

    ### Related ONTAP commands

    - `vserver cifs share access-control show`

    ### Learn more

    - `DOC /protocols/cifs/shares/{svm.uuid}/{share}/acls`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a share-level ACL on a CIFS share.

    ### Related ONTAP commands

    - `vserver cifs share access-control delete`

    ### Learn more

    - `DOC /protocols/cifs/shares/{svm.uuid}/{share}/acls`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the share-level ACL on a CIFS share.

    ### Related ONTAP commands

    - `vserver cifs share access-control show`

    ### Learn more

    - `DOC /protocols/cifs/shares/{svm.uuid}/{share}/acls`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the share-level ACL on a CIFS share.

    ### Related ONTAP commands

    - `vserver cifs share access-control show`

    ### Learn more

    - `DOC /protocols/cifs/shares/{svm.uuid}/{share}/acls`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates a share-level ACL on a CIFS share.

    ### Related ONTAP commands

    - `vserver cifs share access-control modify`

    ### Learn more

    - `DOC /protocols/cifs/shares/{svm.uuid}/{share}/acls`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a share-level ACL on a CIFS share.

    ### Related ONTAP commands

    - `vserver cifs share access-control delete`

    ### Learn more

    - `DOC /protocols/cifs/shares/{svm.uuid}/{share}/acls`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the share-level ACL on CIFS share for a specified user or group.

    ### Related ONTAP commands

    - `vserver cifs share access-control show`

    ### Learn more

    - `DOC /protocols/cifs/shares/{svm.uuid}/{share}/acls`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a share-level ACL on a CIFS share.

    ### Related ONTAP commands

    - `vserver cifs share access-control modify`

    ### Learn more

    - `DOC /protocols/cifs/shares/{svm.uuid}/{share}/acls`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a share-level ACL on a CIFS share.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the share acl.
    - `share` - Existing CIFS share in which to create the share acl.
    - `user_or_group` - Existing user or group name for which the acl is added on the CIFS share.
    - `permission` - Access rights that a user or group has on the defined CIFS share.

    ### Default property values

    - `type` - windows

    ### Related ONTAP commands

    - `vserver cifs share access-control create`

    ### Learn more

    - `DOC /protocols/cifs/shares/{svm.uuid}/{share}/acls`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class CifsShareAclSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the CifsShareAcl object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the cifs_share_acl.

  `permission GET POST PATCH`

    Specifies the access rights that a user or group has on the defined CIFS Share. The following values are allowed:

    - no_access - User does not have CIFS share access
    - read - User has only read access
    - change - User has change access
    - full_control - User has full_control access

    Valid choices:

    - no_access
    - read
    - change
    - full_control
  `type GET POST`

    Specifies the type of the user or group to add to the access control list of a CIFS share. The following values are allowed:

    - windows - Windows user or group
    - unix_user - UNIX user
    - unix_group - UNIX group

    Valid choices:

    - windows
    - unix_user
    - unix_group
  `user_or_group GET POST`

    Specifies the user or group name to add to the access control list of a CIFS share.

    Example: ENGDOMAIN\ad_user